/* --------------------------------------------------------------------------------------------
 * Copyright (c) 2024 TypeFox GmbH (http://www.typefox.io). All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 * ------------------------------------------------------------------------------------------ */
import { MonacoEditorLanguageClientWrapper } from 'monaco-editor-wrapper';
import { languages } from '@codingame/monaco-vscode-editor-api';
const wrapper = new MonacoEditorLanguageClientWrapper();
export const startEditor = async (userConfig, htmlElement, code, codeOriginal) => {
    if (wrapper.isStarted()) {
        console.warn('Editor was already started!');
    }
    else {
        configureCodeEditors(userConfig, code, codeOriginal);
        toggleSwapDiffButton(true);
        await restartEditor(userConfig, htmlElement);
    }
};
export const getWrapper = () => {
    return wrapper;
};
export const updateModel = async (modelUpdate) => {
    if (wrapper.getMonacoEditorApp()?.getConfig().useDiffEditor) {
        await wrapper.updateDiffModel(modelUpdate);
    }
    else {
        await wrapper.updateModel(modelUpdate);
    }
};
export const swapEditors = async (userConfig, htmlElement, code, codeOriginal) => {
    userConfig.wrapperConfig.editorAppConfig.useDiffEditor = !userConfig.wrapperConfig.editorAppConfig.useDiffEditor;
    saveMainCode(!userConfig.wrapperConfig.editorAppConfig.useDiffEditor);
    configureCodeEditors(userConfig, code, codeOriginal);
    await restartEditor(userConfig, htmlElement);
};
export const disposeEditor = async (useDiffEditor) => {
    wrapper.reportStatus();
    toggleSwapDiffButton(false);
    const codeMain = saveMainCode(useDiffEditor);
    await wrapper.dispose();
    return codeMain;
};
const restartEditor = async (userConfig, htmlElement) => {
    await wrapper.dispose();
    await wrapper.initAndStart(userConfig, htmlElement);
    logEditorInfo(userConfig);
};
const configureCodeEditors = (userConfig, code, codeOriginal) => {
    if (userConfig.wrapperConfig.editorAppConfig.useDiffEditor) {
        userConfig.wrapperConfig.editorAppConfig.code = code;
        userConfig.wrapperConfig.editorAppConfig.codeOriginal = codeOriginal;
    }
    else {
        userConfig.wrapperConfig.editorAppConfig.code = code;
    }
};
const saveMainCode = (saveFromDiff) => {
    if (saveFromDiff) {
        return wrapper.getModel(true).getValue();
    }
    else {
        return wrapper.getModel().getValue();
    }
};
const toggleSwapDiffButton = (enabled) => {
    const button = document.getElementById('button-swap');
    if (button !== null) {
        button.disabled = !enabled;
    }
};
const logEditorInfo = (userConfig) => {
    console.log(`# of configured languages: ${languages.getLanguages().length}`);
    console.log(`Main code: ${wrapper.getModel(true)?.getValue() ?? ''}`);
    if (userConfig.wrapperConfig.editorAppConfig.useDiffEditor) {
        console.log(`Modified code: ${wrapper.getModel().getValue()}`);
    }
};
export const getTextContent = async (url) => {
    const response = await fetch(url.href);
    return response.text();
};
//# sourceMappingURL=example-apps-common.js.map