/******************************************************************************
 * Copyright 2021 TypeFox GmbH
 * This program and the accompanying materials are made available under the
 * terms of the MIT License, which is available in the project root.
 ******************************************************************************/
import { inject } from 'langium';
import { createDefaultModule, createDefaultSharedModule } from 'langium/lsp';
import { StatemachineGeneratedModule, StatemachineGeneratedSharedModule } from './generated/module.js';
import { registerValidationChecks, StatemachineValidator } from './statemachine-validator.js';
/**
 * Dependency injection module that overrides Langium default services and contributes the
 * declared custom services. The Langium defaults can be partially specified to override only
 * selected services, while the custom services must be fully specified.
 */
export const StatemachineModule = {
    validation: {
        StatemachineValidator: () => new StatemachineValidator()
    }
};
/**
 * Create the full set of services required by Langium.
 *
 * First inject the shared services by merging two modules:
 *  - Langium default shared services
 *  - Services generated by langium-cli
 *
 * Then inject the language-specific services by merging three modules:
 *  - Langium default language-specific services
 *  - Services generated by langium-cli
 *  - Services specified in this file
 *
 * @param context Optional module context with the LSP connection
 * @returns An object wrapping the shared services and the language-specific services
 */
export function createStatemachineServices(context) {
    const shared = inject(createDefaultSharedModule(context), StatemachineGeneratedSharedModule);
    const statemachine = inject(createDefaultModule({ shared }), StatemachineGeneratedModule, StatemachineModule);
    shared.ServiceRegistry.register(statemachine);
    registerValidationChecks(statemachine);
    return { shared, statemachine };
}
//# sourceMappingURL=statemachine-module.js.map