/* --------------------------------------------------------------------------------------------
 * Copyright (c) 2024 TypeFox GmbH (http://www.typefox.io). All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 * ------------------------------------------------------------------------------------------ */
import { resolve } from 'path';
import { runLanguageServer } from '../../common/language-server-runner.js';
import { LanguageName } from '../../common/server-commons.js';
export const runPythonServer = (baseDir, relativeDir) => {
    const processRunPath = resolve(baseDir, relativeDir);
    runLanguageServer({
        serverName: 'PYRIGHT',
        pathName: '/pyright',
        serverPort: 30001,
        runCommand: LanguageName.node,
        runCommandArgs: [
            processRunPath,
            '--stdio'
        ],
        wsServerOptions: {
            noServer: true,
            perMessageDeflate: false,
            clientTracking: true,
            verifyClient: (clientInfo, callback) => {
                const parsedURL = new URL(`${clientInfo.origin}${clientInfo.req?.url ?? ''}`);
                const authToken = parsedURL.searchParams.get('authorization');
                if (authToken === 'UserAuth') {
                    callback(true);
                }
                else {
                    callback(false);
                }
            }
        }
    });
};
//# sourceMappingURL=main.js.map